import os
from typing import Optional

from pyspark.sql import SparkSession


def get_spark_logger(spark: SparkSession, name: Optional[str] = None):
    log4j_logger = spark._jvm.org.apache.log4j  # noqa
    if name is None:
        name = os.path.basename(__file__)

    return log4j_logger.LogManager.getLogger("pyspark." + name)


import random
import string


def table_name_with_random_suffix(table_name):
    # add random suffix to table name to avoid conflicts
    random_suffix = ''.join(random.choice(string.ascii_lowercase) for _ in range(5))
    return table_name + random_suffix
